@@ -4,7 +4,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 =head1 NAME
 
@@ -90,7 +90,7 @@ sub new
         };
     }
     $ospeed = 9600 if ( !$ospeed || $@ );
-    my $term = Tgetent Term::Cap { 'TERM' => '', 'OSPEED' => $ospeed };
+    my $term = Term::Cap->Tgetent({ 'TERM' => '', 'OSPEED' => $ospeed });
 
     my $this = {};                           # create object
     bless $this, $classname;
@@ -511,7 +511,7 @@ sub getch
             }
             else                                # buffer up the received chars
             {
-                $this->{IN} = CORE::reverse($partial_fn_str) . $this->{IN};
+                $this->{IN} .= CORE::reverse($partial_fn_str);
                 $c = chop( $this->{IN} );
                 $this->puts($c) if ( $this->{ECHO} && ( $c ne "\e" ) );
             }
